@@ -36,8 +36,8 @@ class PCESampler(BaseSamplingElement, sampler_name="PCE_sampler"):
                  sparse=False,
                  growth=False):
         """
-        Create the sampler for the Polynomial Chaos Expansion method using
-        pseudo-spectral projection.
+        Create the sampler for the Polynomial Chaos Expansion using
+        pseudo-spectral projection or regression (Point Collocation).
 
         Parameters
         ----------
@@ -59,7 +59,6 @@ class PCESampler(BaseSamplingElement, sampler_name="PCE_sampler"):
             The quadrature method, in case of projection (default is Gaussian "G").
             The sequence sampler in case of regression (default is Hammersley "M")
 
-
         sparse : bool, optional
             If True, use Smolyak sparse grid instead of normal tensor product
             grid. Default value is False.
@@ -105,7 +104,7 @@ class PCESampler(BaseSamplingElement, sampler_name="PCE_sampler"):
         # Clenshaw-Curtis should be nested if sparse (#139 chaospy issue)
         self.quad_growth = growth
         cc = ['c', 'C', 'clenshaw_curtis', 'Clenshaw_Curtis']
-        if sparse and quadrature_rule in cc:
+        if sparse and rule in cc:
             self.quad_growth = True
 
         # To determinate the PCE vrainte to use
@@ -118,8 +117,8 @@ class PCESampler(BaseSamplingElement, sampler_name="PCE_sampler"):
                 self.rule = "M"
 
             # Generates samples
-            self.n_samples = 2 * len(self.P)
-            nodes = cp.generate_samples(order=self.n_samples,
+            self._n_samples = 2 * len(self.P)
+            nodes = cp.generate_samples(order=self._n_samples,
                                         domain=self.distribution,
                                         rule=self.rule)
 
@@ -132,7 +131,7 @@ class PCESampler(BaseSamplingElement, sampler_name="PCE_sampler"):
                                               sparse=sparse,
                                               growth=self.quad_growth)
             # Number of samples
-            self.n_samples = len(nodes[0])
+            self._n_samples = len(nodes[0])
 
         # Reorganize nodes according to params type: scalar (float, integer) or list
         self._nodes = []
@@ -148,7 +147,7 @@ class PCESampler(BaseSamplingElement, sampler_name="PCE_sampler"):
 
         # Fast forward to specified count, if possible
         self.count = 0
-        if self.count >= self.n_samples:
+        if self.count >= self._n_samples:
             msg = (f"Attempt to start sampler fastforwarded to count {self.count}, "
                    f"but sampler only has {self.n_samples} samples, therefore"
                    f"this sampler will not provide any more samples.")
@@ -163,11 +162,28 @@ class PCESampler(BaseSamplingElement, sampler_name="PCE_sampler"):
     def is_finite(self):
         return True
 
+    @property
+    def n_samples(self):
+        """
+        Number of samples (Ns) of PCE method.
+        - When using pseudo-spectral projection method with tensored
+          quadrature: Ns = (p + 1)**d
+        - When using pseudo-spectral projection method with sparce grid
+          quadratue: Ns = bigO((p + 1)*log(p + 1)**(d-1))
+        - When using regression method: Ns = 2*(p + d)!/p!*d!
+        Where: p is the polynomial degree and d is the number of
+        uncertain parameters.
+
+        Ref: Eck et al. 'A guide to uncertainty quantification and
+        sensitivity analysis for cardiovascular applications' [2016].
+        """
+        return self._n_samples
+
     def is_restartable(self):
         return True
 
     def __next__(self):
-        if self.count < self.n_samples:
+        if self.count < self._n_samples:
             run_dict = {}
             ipar = 0
             for param_name in self.vary.get_keys():
